@@ -3,4 +3,4 @@ utils::globalVariables(c(".", "bin.type", "complete.cases", "dist.b", "dist.g",
 			 "pct", "predict", "sb", "sg", "woe", "combn", "cor", "cutree", "dist", "group", "label",
 			 "label.y", "pchisq", "pnorm", "xtabs", "as.dist", "reg.tree", "segment", "mpred",
 			 "nb.obs", "nb.mod", "dr.mod", "dr.obs", "amse", "as.formula", "auc", "db.vld", "rmse", "bin",
-			 "n.base", "n.target"))
+			 "n.base", "n.target", "n.cs", "n.cs.rev", "y.cs", "y.cs.rev", "y.sum"))
